@@ -7,6 +7,7 @@ SELECT
   CHARACTER_SET_NAME,
   COLLATION_NAME,
   COLUMN_COMMENT,
-  GENERATION_EXPRESSION
+  GENERATION_EXPRESSION,
+  EXTRA
 FROM
   INFORMATION_SCHEMA.COLUMNS
