@@ -11,7 +11,8 @@ FROM
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^APEX_[0-9]{6}$')
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^FLOWS_[0-9]{5}$')
 WHERE
-  REGEXP_LIKE(COLUMNS.OWNER, '${schemas}')
+  REGEXP_LIKE(COLUMNS.OWNER, '${schema-inclusion-rule}')
+  AND REGEXP_LIKE(COLUMNS.OWNER || '.' || COLUMNS.TABLE_NAME, '${table-inclusion-rule}')
   AND COLUMNS.TABLE_NAME NOT LIKE 'BIN$%'
   AND NOT REGEXP_LIKE(COLUMNS.TABLE_NAME, '^(SYS_IOT|MDOS|MDRS|MDRT|MDOT|MDXT)_.*$')
   AND COLUMNS.HIDDEN_COLUMN = 'YES'
