@@ -15,7 +15,8 @@ FROM
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^APEX_[0-9]{6}$')
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^FLOWS_[0-9]{5}$')  
 WHERE
-  REGEXP_LIKE(TABLES.OWNER, '${schemas}')
+  REGEXP_LIKE(TABLES.OWNER, '${schema-inclusion-rule}')
+  AND REGEXP_LIKE(TABLES.OWNER || '.' || TABLES.TABLE_NAME, '${table-inclusion-rule}')
   AND TABLES.TABLE_NAME NOT LIKE 'BIN$%'
   AND NOT REGEXP_LIKE(TABLES.TABLE_NAME, '^(SYS_IOT|MDOS|MDRS|MDRT|MDOT|MDXT)_.*$')
   AND TABLES.NESTED = 'NO'
