@@ -19,7 +19,8 @@ FROM
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^APEX_[0-9]{6}$')
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^FLOWS_[0-9]{5}$')
 WHERE
-  REGEXP_LIKE(CONSTRAINTS.OWNER, '${schemas}')
+  REGEXP_LIKE(CONSTRAINTS.OWNER, '${schema-inclusion-rule}')
+  AND REGEXP_LIKE(CONSTRAINTS.OWNER || '.' || CONSTRAINTS.TABLE_NAME, '${table-inclusion-rule}')
   AND CONSTRAINTS.TABLE_NAME NOT LIKE 'BIN$%'
   AND NOT REGEXP_LIKE(CONSTRAINTS.TABLE_NAME, '^(SYS_IOT|MDOS|MDRS|MDRT|MDOT|MDXT)_.*$')
   AND CONSTRAINT_TYPE IN ('C', 'U', 'P', 'R')
