@@ -13,7 +13,8 @@ FROM
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^APEX_[0-9]{6}$')
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^FLOWS_[0-9]{5}$')
 WHERE
-  REGEXP_LIKE(VIEWS.OWNER, '${schemas}')
+  REGEXP_LIKE(VIEWS.OWNER, '${schema-inclusion-rule}')
+  AND REGEXP_LIKE(VIEWS.OWNER || '.' || VIEWS.VIEW_NAME, '${table-inclusion-rule}')
   AND VIEWS.VIEW_NAME NOT LIKE 'BIN$%'
   AND NOT REGEXP_LIKE(VIEWS.VIEW_NAME, '^(SYS_IOT|MDOS|MDRS|MDRT|MDOT|MDXT)_.*$')
 UNION ALL
@@ -32,6 +33,7 @@ FROM
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^APEX_[0-9]{6}$')
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^FLOWS_[0-9]{5}$')
 WHERE
-  REGEXP_LIKE(MVIEWS.OWNER, '${schemas}')
+  REGEXP_LIKE(MVIEWS.OWNER, '${schema-inclusion-rule}')
+  AND REGEXP_LIKE(MVIEWS.OWNER || '.' || MVIEWS.MVIEW_NAME, '${table-inclusion-rule}')
   AND MVIEWS.MVIEW_NAME NOT LIKE 'BIN$%'
   AND NOT REGEXP_LIKE(MVIEWS.MVIEW_NAME, '^(SYS_IOT|MDOS|MDRS|MDRT|MDOT|MDXT)_.*$')
